@@ -3,10 +3,10 @@ import django_statsd
 
 class TimingCursorWrapper(object):
     def execute(self, *args, **kwargs):
-        with django_statsd.with_('sql.execute'):
+        with django_statsd.with_('sql.%s' % self.db.alias):
             return self.cursor.execute(*args, **kwargs)
 
     def executemany(self, *args, **kwargs):
-        with django_statsd.with_('sql.executemany'):
+        with django_statsd.with_('sql.%s' % self.db.alias):
             return self.cursor.executemany(*args, **kwargs)
 
